
class TypesTestCases:
    """Class representing different types of test cases.

    Attributes:
        type_default (str): The default type of test case.
        type_405 (str): The type of test case for 405 error.
        type_params (str): The type of test case for parameters.
        type_elem (str): The type of test case for elements.
        type_gen (str): The type of test case for generation data.
        type_health (str): The type of test case for health.
        type_env (str): The type of test case for environment.
    """
    type_default = 'default'
    type_405 = '405'
    type_params = 'params'
    type_elem = 'elem'
    type_gen = 'generation_data'
    type_health = 'health'
    type_env = 'env'